# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.
# --------------------------------------------------------------------------------------------
# - Generated by tools/entrypoint_compiler.py: do not edit by hand
"""
OneHotHashVectorizer
"""

__all__ = ["OneHotHashVectorizer"]


from ....entrypoints.transforms_categoricalhashonehotvectorizer import \
    transforms_categoricalhashonehotvectorizer
from ....utils.utils import trace
from ...base_pipeline_item import BasePipelineItem, SingleOutputSignature


class OneHotHashVectorizer(
        BasePipelineItem,
        SingleOutputSignature):
    """

    Categorical hash transform that can be performed on data before
    training a model.


    .. remarks::
        ``OneHotHashVectorizer`` converts a categorical value into an
        indicator
        array by hashing the value and using the hash as an index in the bag.
        If
        the input column is a vector, a single indicator bag is returned for
        it.
        ``OneHotHashVectorizer`` does not currently support handling factor
        data.

    :param number_of_bits: An integer specifying the number of bits to hash into.
        Must be between 1 and 30, inclusive. The default value is 16.

    :param output_kind: A character string that specifies the kind
        of output kind.

        * ``"Bag"``: Outputs a multi-set vector. If the input column is a
          vector of categories, the output contains one vector, where the
        value in
          each slot is the number of occurrences of the category in the input
          vector. If the input column contains a single category, the
        indicator
          vector and the bag vector are equivalent
        * ``"Ind"``: Outputs an indicator vector. The input column is a
        vector
          of categories, and the output contains one indicator vector per
        slot in
          the input column.
        * ``"Key``: Outputs an index. The output is an integer id (between
          1 and the number of categories in the dictionary) of the category.
        * ``"Bin``: Outputs a vector which is the binary representation of
        the category.

        The default value is ``"Bag"``.

    :param random_state: An integer specifying the hashing seed. The default
        value is
        314489979.

    :param ordered: ``True`` to include the position of each term in the
        hash. Otherwise, ``False``. The default value is ``True``.

    :param maximum_number_of_inverts: An integer specifying the limit on the number of keys
        that can be used to generate the slot name. ``0`` means no invert
        hashing; ``-1`` means no limit. While a zero value gives better
        performance, a non-zero value is needed to get meaningful coefficent
        names.
        The default value is ``0``.

    :param params: Additional arguments sent to compute engine.

    .. seealso::
        :py:class:`OneHotVectorizer
        <nimbusml.feature_extraction.categorical.OneHotVectorizer>`

    .. index:: transform, catagory, hash

    Example:
       .. literalinclude:: /../nimbusml/examples/OneHotHashVectorizer.py
              :language: python
    """

    @trace
    def __init__(
            self,
            number_of_bits=16,
            output_kind='Bag',
            random_state=314489979,
            ordered=True,
            maximum_number_of_inverts=0,
            **params):
        BasePipelineItem.__init__(
            self, type='transform', **params)

        self.number_of_bits = number_of_bits
        self.output_kind = output_kind
        self.random_state = random_state
        self.ordered = ordered
        self.maximum_number_of_inverts = maximum_number_of_inverts

    @property
    def _entrypoint(self):
        return transforms_categoricalhashonehotvectorizer

    @trace
    def _get_node(self, **all_args):

        input_columns = self.input
        if input_columns is None and 'input' in all_args:
            input_columns = all_args['input']
        if 'input' in all_args:
            all_args.pop('input')

        output_columns = self.output
        if output_columns is None and 'output' in all_args:
            output_columns = all_args['output']
        if 'output' in all_args:
            all_args.pop('output')

        # validate input
        if input_columns is None:
            raise ValueError(
                "'None' input passed when it cannot be none.")

        if not isinstance(input_columns, list):
            raise ValueError(
                "input has to be a list of strings, instead got %s" %
                type(input_columns))

        # validate output
        if output_columns is None:
            output_columns = input_columns

        if not isinstance(output_columns, list):
            raise ValueError(
                "output has to be a list of strings, instead got %s" %
                type(output_columns))

        algo_args = dict(
            column=[
                dict(
                    Source=i,
                    Name=o) for i,
                o in zip(
                    input_columns,
                    output_columns)] if input_columns else None,
            number_of_bits=self.number_of_bits,
            output_kind=self.output_kind,
            seed=self.random_state,
            ordered=self.ordered,
            maximum_number_of_inverts=self.maximum_number_of_inverts)

        all_args.update(algo_args)
        return self._entrypoint(**all_args)
