# --------------------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License.
# --------------------------------------------------------------------------------------------
# - Generated by tools/entrypoint_compiler.py: do not edit by hand
"""
WordTokenizer
"""

__all__ = ["WordTokenizer"]


from ....entrypoints.transforms_wordtokenizer import transforms_wordtokenizer
from ....utils.utils import trace
from ...base_pipeline_item import BasePipelineItem, DefaultSignature


class WordTokenizer(BasePipelineItem, DefaultSignature):
    """
    **Description**
        The input to this transform is text, and the output is a vector of text containing the words (tokens) in the original text. The separator is space, but can be specified as any other character (or multiple characters) if needed.

    :param char_array_term_separators: Array of single character term
        separator(s). By default uses space character separator.

    :param params: Additional arguments sent to compute engine.

    """

    @trace
    def __init__(
            self,
            char_array_term_separators=None,
            **params):
        BasePipelineItem.__init__(
            self, type='transform', **params)

        self.char_array_term_separators = char_array_term_separators

    @property
    def _entrypoint(self):
        return transforms_wordtokenizer

    @trace
    def _get_node(self, **all_args):

        input_columns = self.input
        if input_columns is None and 'input' in all_args:
            input_columns = all_args['input']
        if 'input' in all_args:
            all_args.pop('input')

        output_columns = self.output
        if output_columns is None and 'output' in all_args:
            output_columns = all_args['output']
        if 'output' in all_args:
            all_args.pop('output')

        # validate input
        if input_columns is None:
            raise ValueError(
                "'None' input passed when it cannot be none.")

        if not isinstance(input_columns, list):
            raise ValueError(
                "input has to be a list of strings, instead got %s" %
                type(input_columns))

        # validate output
        if output_columns is None:
            output_columns = input_columns

        if not isinstance(output_columns, list):
            raise ValueError(
                "output has to be a list of strings, instead got %s" %
                type(output_columns))

        algo_args = dict(
            column=[
                dict(
                    Source=i,
                    Name=o) for i,
                o in zip(
                    input_columns,
                    output_columns)] if input_columns else None,
            char_array_term_separators=self.char_array_term_separators)

        all_args.update(algo_args)
        return self._entrypoint(**all_args)
